lvm_read
========

LabView Measurement file reader
-------------------------------

|pytest|

|binder| to test the *Showcase lvm_read.ipynb*. 

.. |binder| image:: http://mybinder.org/badge.svg 
   :target: http://mybinder.org:/repo/ladisk/lvm_read
.. |pytest| image:: https://github.com/ladisk/lvm_read/actions/workflows/python-package.yml/badge.svg
    :target: https://github.com/ladisk/lvm_read/actions

See also `Specifications <http://www.ni.com/tutorial/4139/en/>`_.

